@@ -13,7 +13,7 @@ pub fn app() -> App<'static> {
                      developer",
                 )
                 .index(1)
-                .required(true),
+                .required_unless_present("completion"),
         )
         .arg(
             Arg::new("copy-message-to-clipboard")
@@ -23,4 +23,11 @@ pub fn app() -> App<'static> {
                 .takes_value(true)
                 .default_value("true"),
         )
+        .arg(Arg::new("completion").long("completion").possible_values(&[
+            "bash",
+            "elvish",
+            "fish",
+            "powershell",
+            "zsh",
+        ]))
 }
